@@ -3,7 +3,8 @@
 . /usr/share/debconf/confmodule
 
 admin_password=$(cat /dev/urandom | tr -dc "[:print:]" | head -c 32)
-admin_email="root@localhost"
+local_domain=$(domainname -f)
+admin_email="root@$local_domain"
 dbc_name="tryton"
 
 # get database settings from dbconfig-common
@@ -22,13 +23,13 @@ fi
 
 TRYTONPASSFILE=`mktemp`
 export TRYTONPASSFILE
-echo $admin_password > $TRYTONPASSFILE
+echo "$admin_password" > "$TRYTONPASSFILE"
 unset admin_password
 
 # The new configuration file is not yet in place, we construct the database url and use that
-uri=postgresql://$dbc_dbuser:$dbc_dbpass@$dbc_dbserver
-if [ ! -z $dbc_dbport ]; then
-    uri="$uri":$dbc_dbport
+uri="postgresql://$dbc_dbuser:$dbc_dbpass@$dbc_dbserver"
+if [ ! -z "$dbc_dbport" ]; then
+    uri="$uri:$dbc_dbport"
 fi
 uri="$uri"/
 export TRYTOND_DATABASE_URI="$uri"
